==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/tr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Sizinle paylaşılmış",
    "Shared with others" : "Diğerleri ile paylaşılmış",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Nothing shared with you yet" : "Sizinle henüz herhangi bir şey paylaşılmamış",
    "Files and folders others share with you will show up here" : "Diğerlerinin sizinle paylaştığı dosya ve klasörler burada görüntülenir",
    "Nothing shared yet" : "Henüz hiçbir şey paylaşılmamış",
    "Files and folders you share will show up here" : "Paylaştığınız dosya ve klasörler burada görüntülenir",
    "No shared links" : "Paylaşılmış bir bağlantı yok",
    "Files and folders you share by link will show up here" : "Bağlantı ile paylaştığınız dosya ve klasörler burada görüntülenir",
    "You can upload into this folder" : "Bu klasöre yükleme yapabilirsiniz",
    "No compatible server found at {remote}" : " {remote} konumunda uyumlu sunucu bulunamadı",
    "Invalid server URL" : "Sunucu adresi geçersiz",
    "Failed to add the public link to your Nextcloud" : "Herkese açık bağlantı Nextcould üzerine eklenemedi",
    "Share" : "Paylaş",
    "No expiration date set" : "Son kullanma tarihi belirtilmemiş",
    "Shared by" : "Paylaşan",
    "Sharing" : "Paylaşım",
    "File shares" : "Dosya paylaşımları",
    "Downloaded via public link" : "Herkese açık bağlantı ile indirildi",
    "Downloaded by {email}" : "{email} tarafından indirildi",
    "{file} downloaded via public link" : "{file} herkese açık bağlantı ile indirildi",
    "{email} downloaded {file}" : "{email} {file} dosyasını indirdi",
    "Shared with group {group}" : "{group} grubuyla paylaşıldı",
    "Removed share for group {group}" : "{group} grubunun paylaşımı kaldırıldı",
    "{actor} shared with group {group}" : "{actor} {group} grubuyla paylaştı",
    "{actor} removed share for group {group}" : "{actor} {group} grubunun paylaşımını kaldırdı",
    "You shared {file} with group {group}" : "{file} dosyasını {group} grubuyla paylaştınız",
    "You removed group {group} from {file}" : "{file} dosyasının {group} grubuyla paylaşımını kaldırdınız",
    "{actor} shared {file} with group {group}" : "{actor} {file} dosyasını {group} grubuyla paylaştı",
    "{actor} removed group {group} from {file}" : "{actor} {file} dosyasının {group} grubuyla paylaşımını kaldırdı",
    "Shared as public link" : "Herkese açık bağlantı olarak paylaştı",
    "Removed public link" : "Herkese açık bağlantı kaldırıldı",
    "Public link expired" : "Herkese açık bağlantının süresi dolmuş",
    "{actor} shared as public link" : "{actor} herkese açık bağlantı olarak paylaştı",
    "{actor} removed public link" : "{actor} herkese açık paylaşım bağlantısını kaldırdı",
    "Public link of {actor} expired" : "{actor} tarafından paylaşılan herkese açık bağlantının süresi dolmuş",
    "You shared {file} as public link" : "{file} dosyasını herkese açık bağlantı olarak paylaştınız",
    "You removed public link for {file}" : "{file} dosyasının herkese açık paylaşım bağlantısını kaldırdınız",
    "Public link expired for {file}" : "{file} için herkese açık bağlantının süresi dolmuş",
    "{actor} shared {file} as public link" : "{actor} {file} dosyasını herkese açık bağlantı olarak paylaştı",
    "{actor} removed public link for {file}" : "{actor} {file} dosyasının herkese açık paylaşım bağlantısını kaldırdı",
    "Public link of {actor} for {file} expired" : "{actor} tarafından paylaşılan {file} dosyası bağlantısının süresi dolmuş",
    "{user} accepted the remote share" : "{user} uzak paylaşımı kabul etti",
    "{user} declined the remote share" : "{user} uzak paylaşımı reddetti",
    "You received a new remote share {file} from {user}" : "{user} kullanıcısından yeni bir uzak {file} dosya paylaşımı aldınız",
    "{user} accepted the remote share of {file}" : "{user} uzak {file} dosyasının paylaşımını kabul etti",
    "{user} declined the remote share of {file}" : "{user} uzak {file} dosyasının paylaşımını reddetti",
    "{user} unshared {file} from you" : "{user} sizinle {file} dosyasının paylaşımını kaldırdı",
    "Shared with {user}" : "{user} ile paylaşıldı",
    "Removed share for {user}" : "{user} kullanıcı ile paylaşım kaldırıldı",
    "{actor} shared with {user}" : "{actor} {user} kullanıcısıyla paylaştı",
    "{actor} removed share for {user}" : "{actor} {user} kullanıcısının paylaşımını kaldırdı",
    "Shared by {actor}" : "{actor} tarafından paylaşıldı",
    "{actor} removed share" : "{actor} paylaşımı kaldırdı",
    "You shared {file} with {user}" : "{file} dosyasını {user} kullanıcısıyla paylaştınız",
    "You removed {user} from {file}" : "{file} dosyasının {user} kullanıcısıyla paylaşımını kaldırdınız",
    "{actor} shared {file} with {user}" : "{actor} {file} dosyasını {user} kullanıcısı ile paylaştı",
    "{actor} removed {user} from {file}" : "{actor} {file} dosyasının {user} kullanıcısıyla paylaşımını kaldırdı",
    "{actor} shared {file} with you" : "{actor} {file} dosyasını sizinle paylaştı",
    "{actor} removed you from {file}" : "{actor} {file} dosyasının sizinle paylaşımını kaldırdı",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "E-posta ya da herkese açık bağlatı ile paylaşılan bir dosya ya da klasör <strong>indirildi</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>Başka bir sunucudan</strong> bir dosya ya da klasör paylaşıldı",
    "A file or folder has been <strong>shared</strong>" : "Bir dosya ya da klasör <strong>paylaşıldı</strong>",
    "Wrong share ID, share doesn't exist" : "Paylaşım kimliği yanlış. Paylaşım bulunamadı",
    "could not delete share" : "paylaşım kaldırılamadı",
    "Could not delete share" : "Paylaşım kaldırılamadı",
    "Please specify a file or folder path" : "Lütfen bir dosya ya da klasör yolu belirtin",
    "Wrong path, file/folder doesn't exist" : "Yol yanlış. Dosya ya da klasör bulunamadı",
    "Could not create share" : "Paylaşılamadı",
    "invalid permissions" : "izinler geçersiz",
    "Please specify a valid user" : "Lütfen geçerli bir kullanıcı belirtin",
    "Group sharing is disabled by the administrator" : "Grup paylaşımı yönetici tarafından devre dışı bırakılmış",
    "Please specify a valid group" : "Lütfen geçerli bir grup belirtin",
    "Public link sharing is disabled by the administrator" : "Herkese açık bağlantı paylaşımı yönetici tarafından devre dışı bırakılmış",
    "Public upload disabled by the administrator" : "Herkese açık yükleme yönetici tarafından devre dışı bırakılmış",
    "Public upload is only possible for publicly shared folders" : "Herkese açık yükleme ancak herkese açık paylaşılmış klasörlere yapılabilir",
    "Invalid date, date format must be YYYY-MM-DD" : "Tarih geçersiz. Tarih biçimi YYYY-AA-GG olmalıdır",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Arka uç %s türündeki paylaşımlara izin vermediğinden %s paylaşılamadı",
    "You cannot share to a Circle if the app is not enabled" : "Uygulama etkinleştirilmemiş ise bir Çevre ile paylaşamazsınız",
    "Please specify a valid circle" : "Lütfen geçerli bir çevre belirtin",
    "Unknown share type" : "Paylaşım türü bilinmiyor",
    "Not a directory" : "Bir klasör değil",
    "Could not lock path" : "Yol kilitlenemedi",
    "Wrong or no update parameter given" : "Parametre yanlış ya da herhangi bir parametre belirtilmemiş",
    "Can't change permissions for public share links" : "Herkese açık paylaşılan bağlantıların erişim hakları değiştirilemez",
    "Cannot increase permissions" : "Erişim izinleri yükseltilemez",
    "%s is publicly shared" : "%s herkese açık olarak paylaşıldı",
    "Share API is disabled" : "Paylaşım API arayüzü devre dışı",
    "File sharing" : "Dosya paylaşımı",
    "This share is password-protected" : "Bu paylaşım parola korumalı",
    "The password is wrong. Try again." : "Parola yanlış. Yeniden deneyin.",
    "Password" : "Parola",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt yok",
    "Name" : "Ad",
    "Share time" : "Paylaşma zamanı",
    "Expiration date" : "Son kullanım tarihi",
    "Sorry, this link doesn’t seem to work anymore." : "Maalesef, bu bağlantı artık çalışmıyor gibi görünüyor.",
    "Reasons might be:" : "Nedenleri şunlar olabilir:",
    "the item was removed" : "öge silinmiş",
    "the link expired" : "bağlantı süresi dolmuş",
    "sharing is disabled" : "paylaşım devre dışı bırakılmış",
    "For more info, please ask the person who sent this link." : "Ayrıntılı bilgi almak için bu bağlantıyı aldığınız kişi ile görüşün.",
    "Add to your Nextcloud" : "Nextcloud hesabınıza ekleyin",
    "Download" : "İndir",
    "Download %s" : "%s İndir",
    "Direct link" : "Doğrudan bağlantı",
    "Upload files to %s" : "Dosyaları %s konumuna yükle",
    "Select or drop files" : "Dosyaları seçin ya da sürükleyip bırakın",
    "Uploading files…" : "Dosyalar yükleniyor...",
    "Uploaded files:" : "Yüklenmiş dosyalar:"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/tr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Sizinle paylaşılmış",
    "Shared with others" : "Diğerleri ile paylaşılmış",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Nothing shared with you yet" : "Sizinle henüz herhangi bir şey paylaşılmamış",
    "Files and folders others share with you will show up here" : "Diğerlerinin sizinle paylaştığı dosya ve klasörler burada görüntülenir",
    "Nothing shared yet" : "Henüz hiçbir şey paylaşılmamış",
    "Files and folders you share will show up here" : "Paylaştığınız dosya ve klasörler burada görüntülenir",
    "No shared links" : "Paylaşılmış bir bağlantı yok",
    "Files and folders you share by link will show up here" : "Bağlantı ile paylaştığınız dosya ve klasörler burada görüntülenir",
    "You can upload into this folder" : "Bu klasöre yükleme yapabilirsiniz",
    "No compatible server found at {remote}" : " {remote} konumunda uyumlu sunucu bulunamadı",
    "Invalid server URL" : "Sunucu adresi geçersiz",
    "Failed to add the public link to your Nextcloud" : "Herkese açık bağlantı Nextcould üzerine eklenemedi",
    "Share" : "Paylaş",
    "No expiration date set" : "Son kullanma tarihi belirtilmemiş",
    "Shared by" : "Paylaşan",
    "Sharing" : "Paylaşım",
    "File shares" : "Dosya paylaşımları",
    "Downloaded via public link" : "Herkese açık bağlantı ile indirildi",
    "Downloaded by {email}" : "{email} tarafından indirildi",
    "{file} downloaded via public link" : "{file} herkese açık bağlantı ile indirildi",
    "{email} downloaded {file}" : "{email} {file} dosyasını indirdi",
    "Shared with group {group}" : "{group} grubuyla paylaşıldı",
    "Removed share for group {group}" : "{group} grubunun paylaşımı kaldırıldı",
    "{actor} shared with group {group}" : "{actor} {group} grubuyla paylaştı",
    "{actor} removed share for group {group}" : "{actor} {group} grubunun paylaşımını kaldırdı",
    "You shared {file} with group {group}" : "{file} dosyasını {group} grubuyla paylaştınız",
    "You removed group {group} from {file}" : "{file} dosyasının {group} grubuyla paylaşımını kaldırdınız",
    "{actor} shared {file} with group {group}" : "{actor} {file} dosyasını {group} grubuyla paylaştı",
    "{actor} removed group {group} from {file}" : "{actor} {file} dosyasının {group} grubuyla paylaşımını kaldırdı",
    "Shared as public link" : "Herkese açık bağlantı olarak paylaştı",
    "Removed public link" : "Herkese açık bağlantı kaldırıldı",
    "Public link expired" : "Herkese açık bağlantının süresi dolmuş",
    "{actor} shared as public link" : "{actor} herkese açık bağlantı olarak paylaştı",
    "{actor} removed public link" : "{actor} herkese açık paylaşım bağlantısını kaldırdı",
    "Public link of {actor} expired" : "{actor} tarafından paylaşılan herkese açık bağlantının süresi dolmuş",
    "You shared {file} as public link" : "{file} dosyasını herkese açık bağlantı olarak paylaştınız",
    "You removed public link for {file}" : "{file} dosyasının herkese açık paylaşım bağlantısını kaldırdınız",
    "Public link expired for {file}" : "{file} için herkese açık bağlantının süresi dolmuş",
    "{actor} shared {file} as public link" : "{actor} {file} dosyasını herkese açık bağlantı olarak paylaştı",
    "{actor} removed public link for {file}" : "{actor} {file} dosyasının herkese açık paylaşım bağlantısını kaldırdı",
    "Public link of {actor} for {file} expired" : "{actor} tarafından paylaşılan {file} dosyası bağlantısının süresi dolmuş",
    "{user} accepted the remote share" : "{user} uzak paylaşımı kabul etti",
    "{user} declined the remote share" : "{user} uzak paylaşımı reddetti",
    "You received a new remote share {file} from {user}" : "{user} kullanıcısından yeni bir uzak {file} dosya paylaşımı aldınız",
    "{user} accepted the remote share of {file}" : "{user} uzak {file} dosyasının paylaşımını kabul etti",
    "{user} declined the remote share of {file}" : "{user} uzak {file} dosyasının paylaşımını reddetti",
    "{user} unshared {file} from you" : "{user} sizinle {file} dosyasının paylaşımını kaldırdı",
    "Shared with {user}" : "{user} ile paylaşıldı",
    "Removed share for {user}" : "{user} kullanıcı ile paylaşım kaldırıldı",
    "{actor} shared with {user}" : "{actor} {user} kullanıcısıyla paylaştı",
    "{actor} removed share for {user}" : "{actor} {user} kullanıcısının paylaşımını kaldırdı",
    "Shared by {actor}" : "{actor} tarafından paylaşıldı",
    "{actor} removed share" : "{actor} paylaşımı kaldırdı",
    "You shared {file} with {user}" : "{file} dosyasını {user} kullanıcısıyla paylaştınız",
    "You removed {user} from {file}" : "{file} dosyasının {user} kullanıcısıyla paylaşımını kaldırdınız",
    "{actor} shared {file} with {user}" : "{actor} {file} dosyasını {user} kullanıcısı ile paylaştı",
    "{actor} removed {user} from {file}" : "{actor} {file} dosyasının {user} kullanıcısıyla paylaşımını kaldırdı",
    "{actor} shared {file} with you" : "{actor} {file} dosyasını sizinle paylaştı",
    "{actor} removed you from {file}" : "{actor} {file} dosyasının sizinle paylaşımını kaldırdı",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "E-posta ya da herkese açık bağlatı ile paylaşılan bir dosya ya da klasör <strong>indirildi</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>Başka bir sunucudan</strong> bir dosya ya da klasör paylaşıldı",
    "A file or folder has been <strong>shared</strong>" : "Bir dosya ya da klasör <strong>paylaşıldı</strong>",
    "Wrong share ID, share doesn't exist" : "Paylaşım kimliği yanlış. Paylaşım bulunamadı",
    "could not delete share" : "paylaşım kaldırılamadı",
    "Could not delete share" : "Paylaşım silinemedi",
    "Please specify a file or folder path" : "Lütfen bir dosya ya da klasör yolu belirtin",
    "Wrong path, file/folder doesn't exist" : "Yol yanlış. Dosya ya da klasör bulunamadı",
    "Could not create share" : "Paylaşılamadı",
    "invalid permissions" : "izinler geçersiz",
    "Please specify a valid user" : "Lütfen geçerli bir kullanıcı belirtin",
    "Group sharing is disabled by the administrator" : "Grup paylaşımı yönetici tarafından devre dışı bırakılmış",
    "Please specify a valid group" : "Lütfen geçerli bir grup belirtin",
    "Public link sharing is disabled by the administrator" : "Herkese açık bağlantı paylaşımı yönetici tarafından devre dışı bırakılmış",
    "Public upload disabled by the administrator" : "Herkese açık yükleme yönetici tarafından devre dışı bırakılmış",
    "Public upload is only possible for publicly shared folders" : "Herkese açık yükleme ancak herkese açık paylaşılmış klasörlere yapılabilir",
    "Invalid date, date format must be YYYY-MM-DD" : "Tarih geçersiz. Tarih biçimi YYYY-AA-GG olmalıdır",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Arka uç %s türündeki paylaşımlara izin vermediğinden %s paylaşılamadı",
    "You cannot share to a Circle if the app is not enabled" : "Uygulama etkinleştirilmemiş ise bir Çevre ile paylaşamazsınız",
    "Please specify a valid circle" : "Lütfen geçerli bir çevre belirtin",
    "Unknown share type" : "Paylaşım türü bilinmiyor",
    "Not a directory" : "Bir klasör değil",
    "Could not lock path" : "Yol kilitlenemedi",
    "Wrong or no update parameter given" : "Parametre yanlış ya da herhangi bir parametre belirtilmemiş",
    "Can't change permissions for public share links" : "Herkese açık paylaşılan bağlantıların erişim hakları değiştirilemez",
    "Cannot increase permissions" : "Erişim izinleri yükseltilemez",
    "%s is publicly shared" : "%s herkese açık olarak paylaşıldı",
    "Share API is disabled" : "Paylaşım API arayüzü devre dışı",
    "This share is password-protected" : "Bu paylaşım parola korumalı",
    "The password is wrong. Try again." : "Parola yanlış. Yeniden deneyin.",
    "Password" : "Parola",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt yok",
    "Name" : "Ad",
    "Share time" : "Paylaşma zamanı",
    "Expiration date" : "Son kullanma tarihi",
    "Sorry, this link doesn’t seem to work anymore." : "Maalesef, bu bağlantı artık çalışmıyor gibi görünüyor.",
    "Reasons might be:" : "Nedenleri şunlar olabilir:",
    "the item was removed" : "öge silinmiş",
    "the link expired" : "bağlantı süresi dolmuş",
    "sharing is disabled" : "paylaşım devre dışı bırakılmış",
    "For more info, please ask the person who sent this link." : "Ayrıntılı bilgi almak için bu bağlantıyı aldığınız kişi ile görüşün.",
    "shared by %s" : "%s tarafından paylaşıldı",
    "Add to your Nextcloud" : "Nextcloud hesabınıza ekleyin",
    "Download" : "İndir",
    "Download %s" : "%s İndir",
    "Direct link" : "Doğrudan bağlantı",
    "Upload files to %s" : "Dosyaları %s konumuna yükle",
    "Select or drop files" : "Dosyaları seçin ya da sürükleyip bırakın",
    "Uploading files…" : "Dosyalar yükleniyor...",
    "Uploaded files:" : "Yüklenmiş dosyalar:"
},
"nplurals=2; plural=(n > 1);");
